@@ -1,5 +1,6 @@
 use super::routes::*;
 use serde_derive::Deserialize;
+use serde_json::Error;
 use std::fs;
 use std::io::prelude::*;
 use toml::from_str;
@@ -17,7 +18,7 @@ pub enum Template {
     Basic,
     Math,
     Theatre,
-    MKPB,
+    Book,
 }
 #[derive(Deserialize)]
 pub struct Project {
@@ -34,13 +35,29 @@ pub struct Document {
     pub document_class: String,
     pub packages: Vec<String>,
 }
+#[derive(Deserialize)]
+pub struct List {
+    pub template: String,
+    pub about: String,
+}
 
-impl Template {
-    pub fn list() {
-        println!("Basic Template => Basic");
-        println!("Math Template => Math");
-        println!("Theatre Template => Theatre");
-        println!("MKProjects Book Template => MKPB");
+impl List {
+    pub fn read(path: &str) -> Result<Vec<Self>, Error> {
+        let mut file = fs::File::open(path).expect("Unable to open file");
+        let mut contents = String::new();
+        file.read_to_string(&mut contents)
+            .expect("Unable to read file");
+        let list: Vec<List> = serde_json::from_str(&contents)?;
+        Ok(list)
+    }
+    pub fn list(path: &str) {
+        let json = Self::read(path).expect("Unable to read list.json");
+        println!("//////////////////////////////////////");
+        println!("// List of available templates:");
+        println!("//////////////////////////////////////");
+        for item in json {
+            println!("// {} => {}", item.template, item.about);
+        }
     }
 }
 
@@ -55,14 +72,22 @@ impl Config {
             "Basic" => Template::Basic,
             "Math" => Template::Math,
             "Theatre" => Template::Theatre,
-            "MKPB" => Template::MKPB,
+            "Book" => Template::Book,
             _ => Template::Basic,
         }
     }
-    pub fn config(path: &str) -> Self {
-        let config = std::fs::read_to_string(path).unwrap();
-        let config: Self = from_str(&config).unwrap();
-        config
+    pub fn config(path: &Option<String>) -> Self {
+        match path {
+            Some(path) => {
+                let config = std::fs::read_to_string(path).expect("Unable to read config file");
+                from_str(&config).expect("Unable to parse config file")
+            }
+            None => {
+                let config =
+                    std::fs::read_to_string("config.toml").expect("Unable to read config file");
+                from_str(&config).expect("Unable to parse config file")
+            }
+        }
     }
     pub fn adjust(&self, path: &str) {
         let title = format!("\\title{{{}}}", self.Project.title);
@@ -92,17 +117,22 @@ impl Config {
             .append(true)
             .open(path)
             .expect("Couldn't append to file");
-        
-            let p: Vec<String> = self.Document.packages.iter().map(|x| format!("\\usepackage{{{}}}", x)).collect();
-            let p = p.join("\n");
-            write!(file, "{}", p).expect("Couldn't write to file");
+
+        let p: Vec<String> = self
+            .Document
+            .packages
+            .iter()
+            .map(|x| format!("\\usepackage{{{}}}", x))
+            .collect();
+        let p = p.join("\n");
+        write!(file, "{}", p).expect("Couldn't write to file");
     }
 }
 
 const CONFIG_TOML: &str = r#"[Project]
 author = "Author"
 title = "Title"
-date = "\today"
+date = "\\today"
 project_name = "Project Name"
 template = "Math" #Make sure to have first letter upercased
 
