@@ -1,40 +1,48 @@
 mod create;
 use create::config::Config;
-use create::config::Template;
+use create::config::{List, Template};
+use create::mkproj_book::create as mkcreate;
 use create::routes::create;
 use structopt::StructOpt;
-
 #[derive(StructOpt, Debug)]
 #[structopt(
     name = "texcreate",
     about = "Create LaTeX projects using prebuilt templates"
 )]
-enum CLI {
+/// All TexCreate Subcommands
+pub enum CLI {
     #[structopt(about = "Initialize a config.toml file")]
+    /// Initialize with `texcreate init`
     Init,
     #[structopt(about = "Create a LaTeX Project with a specified name & template")]
+    /// Create project with `texcreate create -t <template> -n <name>`
     Create {
         #[structopt(short = "t", long = "template", help = "Template to use")]
+        /// Template to use
         template: String,
         #[structopt(short = "n", long = "name", help = "Name of the project")]
+        /// Project name
         name: String,
         #[structopt(
             short = "d",
             long = "directory",
             help = "Directory to create the project in"
         )]
+        /// Optional output directory
         path: Option<String>,
     },
     #[structopt(about = "Lists all the available templates")]
+    /// List all available templates `texcreate list`
     List,
     #[structopt(about = "Import a config.toml to create project")]
+    /// Create project with a config.toml file `texcreate import -f config.toml`
     Import {
         #[structopt(short, long)]
-        file: String,
+        file: Option<String>,
     },
 }
-
-fn main() {
+#[tokio::main]
+async fn main() {
     let CLI = CLI::from_args();
     match CLI {
         CLI::Init => Config::init(),
@@ -51,7 +59,7 @@ fn main() {
             ("Theatre", None) => create(&name, ".", "Theatre"),
             (_, _) => println!("Please specify a template"),
         },
-        CLI::List => Template::list(),
+        CLI::List => List::list("list.json"),
         CLI::Import { file } => {
             let conf = Config::config(&file);
             match conf.from_template() {
@@ -79,7 +87,14 @@ fn main() {
                     ));
                     conf.add_packages(&format!("./{}/structure.tex", conf.Project.project_name));
                 }
-                _ => println!("Error in {}, make sure template is valid", &file),
+                Template::Book => mkcreate(
+                    &conf.Project.project_name,
+                    &conf.Project.title,
+                    &conf.Project.author,
+                )
+                .await
+                .unwrap(),
+                _ => println!("Make sure template is valid"),
             }
         }
     }
